@@ -24,12 +24,7 @@ package ykpiv
 //      when I build it. For now this will keep it quiet :\
 
 /*
-#cgo darwin LDFLAGS: -L /usr/local/lib -lykpiv
-#cgo darwin CFLAGS: -I/usr/local/include/ykpiv/
-#cgo linux LDFLAGS: -lykpiv -Wl,--allow-multiple-definition
-#cgo linux CFLAGS: -I/usr/include/ykpiv/
-#cgo windows CFLAGS: -I./win/include/ykpiv/
-#cgo windows LDFLAGS: ./win/lib/libykpiv.dll.a
+#cgo pkg-config: ykpiv
 #include <ykpiv.h>
 #include <stdlib.h>
 */
